/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.geobackend.sde.datasources;

import org.apache.log4j.Logger;

/**
 * The class <code>ResultSet</code> fulfills the following purposes:
 * <ol>
 * <li>Providing an abstract object for dealing with result sets.</li>
 * </ol>
 *
 * @author blume
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public abstract class ResultSet implements java.sql.ResultSet {

    /**
     * Default Logging instance
     */
    private static Logger sLogger = Logger.getLogger(ResultSet.class);

    /**
     * Returns the number of hits.
     * @return count of results.
     */
    public abstract int getCount();

    /**
     * Returns the number of columns returned through the query.
     * @return the number of columns.
     */
    public abstract int getNumberOfColumns();

    /**
     * A ResultSet can tell about the concrete definition of each column.
     * This method returns an array of ColDefinition-Objects.
     * @return the definitions describing the result set.
     */
    public abstract ColDefinition[] getColumnDefinitions();

    /**
     * Returns an array of Rows. The rows contain the "content" of the current ResultSet.
     *
     * @return the results itself.
     */
    public abstract Row[] getResults();

}
